@@ -39,9 +39,11 @@
 #include "storage.h"
 #include "applets.h"
 #include "suid.h"
+#include "parser.h"
 
 
 #define TS_DEV "/dev/touchscreen/0raw"
+#define PROC_BATTERY "/proc/asic/battery"
 
 /* local types and structs */
 
@@ -91,7 +93,12 @@ static struct h3600_battery battery_val;
 float bperc;
 gchar percstr[9];
 gchar tmp[128];
+gboolean islearning = FALSE;
 
+	parse_file(PROC_BATTERY," Is learning? %*s %s",tmp);
+	if (strstr(tmp,"yes"))
+		islearning = TRUE;
+	
 	if (ioctl(TSfd, GET_BATTERY_STATUS, &battery_val) != 0)
 		return TRUE;
 
@@ -127,34 +134,39 @@ gchar tmp[128];
 
 	switch (battery_val.battery[0].status) {
 		case H3600_BATT_STATUS_HIGH:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: high"));
+			sprintf(tmp,"%s",_("Status: high"));
 			break;
 		case H3600_BATT_STATUS_LOW:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: low"));
+			sprintf(tmp,"%s",_("Status: low"));
 			break;
 		case H3600_BATT_STATUS_CRITICAL:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: critical"));
+			sprintf(tmp,"%s",_("Status: critical"));
 			break;
 		case H3600_BATT_STATUS_CHARGING:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: charging"));
+			sprintf(tmp,"%s",_("Status: charging"));
 			break;
 		case H3600_BATT_STATUS_CHARGE_MAIN:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: charge main"));
+			sprintf(tmp,"%s",_("Status: charge main"));
 			break;
 		case H3600_BATT_STATUS_DEAD:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: dead"));
+			sprintf(tmp,"%s",_("Status: dead"));
 			break;
 		case H3600_BATT_STATUS_FULL:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: full"));
+			sprintf(tmp,"%s",_("Status: full"));
 			break;
 		case H3600_BATT_STATUS_NOBATT:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: no battery"));
+			sprintf(tmp,"%s",_("Status: no battery"));
 			break;
 		default:
-			gtk_label_set_text(GTK_LABEL(batt_int.lstate),_("Status: unknown"));
+			sprintf(tmp,"%s",_("Status: unknown"));
 			break;
 	};
 
+	if (islearning)
+		sprintf(tmp+strlen(tmp)," (%s)",_("learning"));
+	
+	gtk_label_set_text(GTK_LABEL(batt_int.lstate),tmp);
+
 	sprintf(tmp,"%s: %d mV",_("Voltage"),battery_val.battery[0].voltage * 5000 / 1024);
 	gtk_label_set_text(GTK_LABEL(batt_int.lvoltage),tmp);
 
@@ -254,13 +266,21 @@ Battery_Build_Objects (void)
 	static GtkWidget *bar_batt_int;
 	t_infowidgets batt;
 	int i;
+	GtkWidget *viewport = gtk_viewport_new (NULL, NULL);
+	GtkWidget *sw = gtk_scrolled_window_new (NULL, NULL);
 	
-	init_device();
-	
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
+				  GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_container_add (GTK_CONTAINER (sw),viewport);
+	gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport), GTK_SHADOW_NONE);
+
 	vbox = gtk_vbox_new (FALSE, 1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox),
 					gpe_get_border ());
-
+	gtk_container_add (GTK_CONTAINER (viewport), vbox);
+	
+	init_device();
+	
 	for (i=0;i<2;i++)
 	{
 		if (i==0) 
@@ -317,5 +337,5 @@ Battery_Build_Objects (void)
 	update_bat_values(NULL);
 	
 	gtk_timeout_add (4000, (GtkFunction) update_bat_values, NULL);
-	return vbox;
+	return sw;
 }
