@@ -32,7 +32,6 @@
 #include "ipaqscreen.h"
 #include "unimplemented.h"
 #include "kbd.h"
-#include "keyboard.h"
 #include "network.h"
 #include "theme.h"
 #include "keyctl.h"
@@ -45,6 +44,7 @@
 #include "serial.h"
 #ifdef PACKAGETOOL		
 #include "packages.h"
+#include "keyboard.h"
 #endif
 #include "cardinfo.h"
 #include "tasks.h"
@@ -93,14 +93,12 @@ struct Applet applets[]=
 		"Screen" , "ipaqscreen", "Screen Setup", PREFIX "/share/pixmaps/gpe-config-ipaqscreen.png"},
     { &Kbd_Build_Objects, &Unimplemented_Free_Objects, &Kbd_Save, &Kbd_Restore ,
 		"vKeyboard" ,"kbd", "Virtual Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-kbd.png"},
-    { &Keyboard_Build_Objects, &Unimplemented_Free_Objects, &Keyboard_Save, &Keyboard_Restore ,
-		"Keyboard" ,"keyboard", "External Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-keyboard.png"},
     { &Keyctl_Build_Objects, &Unimplemented_Free_Objects, &Keyctl_Save, &Keyctl_Restore ,
 		"Buttons" ,"keyctl", "Button Configuration",PREFIX "/share/pixmaps/gpe-config-keyctl.png"},
     { &Network_Build_Objects, &Network_Free_Objects, &Network_Save, &Network_Restore ,
 		"Network" ,"network","IP Addresses",PREFIX "/share/pixmaps/gpe-config-network.png"},
     { &Theme_Build_Objects, &Unimplemented_Free_Objects, &Theme_Save, &Theme_Restore ,
-		"Theme" ,"theme", "Global Appearance Setup",PREFIX "/share/pixmaps/gpe-config-theme.png"},
+		"Theme" ,"theme", "Look and Feel",PREFIX "/share/pixmaps/gpe-config-theme.png"},
     { &Sleep_Build_Objects, &Unimplemented_Free_Objects, &Sleep_Save, &Sleep_Restore ,
 		"Sleep" ,"sleep","Sleep Configuration",PREFIX "/share/pixmaps/gpe-config-sleep.png"},
     { &Ownerinfo_Build_Objects, &Ownerinfo_Free_Objects, &Ownerinfo_Save, &Ownerinfo_Restore,
@@ -118,6 +116,8 @@ struct Applet applets[]=
 #ifdef PACKAGETOOL		
     { &Packages_Build_Objects, &Packages_Free_Objects, &Unimplemented_Save, &Packages_Restore ,
 		"Packages" ,"packages","Add and Remove packages",PREFIX "/share/pixmaps/gpe-config-packages.png"},
+    { &Keyboard_Build_Objects, &Unimplemented_Free_Objects, &Keyboard_Save, &Keyboard_Restore ,
+		"Keyboard" ,"keyboard", "External Keyboard Setup",PREFIX "/share/pixmaps/gpe-config-keyboard.png"},
 #endif		
     { &Unimplemented_Build_Objects, &Unimplemented_Free_Objects, &Unimplemented_Save, &Unimplemented_Restore ,
 		"Task nameserver" ,"task_nameserver","Task for changing nameserver", NULL}
@@ -133,18 +133,11 @@ struct gpe_icon my_icons[] = {
   { "exit" },
   { "ownerphoto", "tux-48" },
   { "warning16", "warning16" },
-  { "menu-insert", PREFIX "/share/pixmaps/menu-insert.png" }, 
-  { "menu-eject", PREFIX "/share/pixmaps/menu-eject.png" }, 
-  { "menu-suspend", PREFIX "/share/pixmaps/menu-suspend.png" }, 
-  { "menu-resume", PREFIX "/share/pixmaps/menu-resume.png" }, 
-  { "menu-reset", PREFIX "/share/pixmaps/menu-reset.png" }, 
-  { "menu-reset2", PREFIX "/share/pixmaps/menu-reset2.png" }, 
-  { "menu-assign", PREFIX "/share/pixmaps/menu-assign.png" }, 
   { "icon", NULL },
   { NULL, NULL }
 };
 
-#define count_icons 17
+#define count_icons 10
 
 int applets_nb = sizeof(applets) / sizeof(struct Applet);
 
@@ -153,7 +146,10 @@ void Save_Callback()
 {
   applets[self.cur_applet].Save();
   if(self.alone_applet)
+  {
+    gtk_main_quit();
     gtk_exit(0);
+  }
 }
 
 
@@ -161,7 +157,10 @@ void Restore_Callback()
 {
   applets[self.cur_applet].Restore();
   if(self.alone_applet)
+  {
+    gtk_main_quit();
     gtk_exit(0);
+  }
 }
 
 
@@ -258,7 +257,7 @@ void make_container()
 
   hbuttons = gtk_hbutton_box_new();
   gtk_box_pack_end(GTK_BOX(self.vbox),hbuttons, FALSE, TRUE, 0);
-  gtk_container_set_border_width (GTK_CONTAINER (hbuttons), gpe_get_border());
+  gtk_container_set_border_width (GTK_CONTAINER (hbuttons), gpe_get_boxspacing() );
 
   self.cancel = gpe_button_new_from_stock(GTK_STOCK_CANCEL,GPE_BUTTON_TYPE_BOTH);
   gtk_box_pack_start(GTK_BOX(hbuttons),self.cancel,FALSE, TRUE, 0);
